@@ -1,4 +1,4 @@
-/* $Id: midgard.c 23835 2009-11-02 08:05:38Z piotras $
+/* $Id: midgard.c 24523 2009-12-21 16:40:34Z piotras $
  *
  * Copyright (C) 2007 Piotr Pokora <piotrek.pokora@gmail.com>
  *
@@ -37,10 +37,86 @@ const char *midgard_version()
 	return MIDGARD_LIB_VERSION;
 }
 
+/* A helper funtion which is registered as string to float 
+ * convertion one. GGtype system doesn't support such conversion,
+ * and what is more, such convesrion must be done using plain C locale
+ * for SQL safety. */
+static void __transform_string_to_float (const GValue *src_val, GValue *dest_val)
+{
+	g_assert (src_val != NULL);
+	g_assert (dest_val != NULL);
+
+	g_assert (G_VALUE_HOLDS_FLOAT (dest_val));
+
+	gchar *lstring = setlocale(LC_NUMERIC, "0");
+	setlocale(LC_NUMERIC, "C");
+
+	const gchar *string_float = g_value_get_string (src_val);
+
+	if (!string_float) {
+
+		g_value_set_float (dest_val, 0.00);
+
+	} else {
+
+		g_value_set_float (dest_val, atof (string_float));
+	}
+
+	setlocale(LC_ALL, lstring);
+
+	return;
+}
+
+/* A helper function whch transforms string to boolean */
+static void __transform_string_to_boolean (const GValue *src_val, GValue *dest_val)
+{
+	g_assert (src_val != NULL);
+	g_assert (dest_val != NULL);
+
+	g_assert (G_VALUE_HOLDS_BOOLEAN (dest_val));
+
+	const gchar *_str = g_value_get_string (src_val);
+
+	if (!_str || (_str && *_str == '\0')) {
+		g_value_set_boolean (dest_val, FALSE);
+		return;
+	}
+
+	/* Stringified boolean */
+	if (g_str_equal (_str, "TRUE")) {
+		g_value_set_boolean (dest_val, TRUE);
+		return;
+	}
+
+	if (g_str_equal (_str, "true")) {
+		g_value_set_boolean (dest_val, TRUE);
+		return;
+	}
+
+	if (g_str_equal (_str, "FALSE")) {
+		g_value_set_boolean (dest_val, FALSE);
+		return;
+	}
+
+	if (g_str_equal (_str, "false")) {
+		g_value_set_boolean (dest_val, FALSE);
+		return;
+	}
+
+	gint i = atoi (_str);
+
+	if (i > 0)
+		g_value_set_boolean (dest_val, TRUE);
+	else 
+		g_value_set_boolean (dest_val, FALSE);
+
+	return;
+}
+
 void midgard_init() 
 {	
 	GType type;
-	/* g_type_init_with_debug_flags(G_TYPE_DEBUG_OBJECTS | G_TYPE_DEBUG_NONE); */
+	g_type_init_with_debug_flags(G_TYPE_DEBUG_OBJECTS | G_TYPE_DEBUG_MASK); 
 
 #ifdef HAVE_LIBGDA_4
 	gda_init ();
@@ -83,6 +159,10 @@ void midgard_init()
 	type = MIDGARD_TYPE_VIEW;
 	g_assert(type != 0);
 	g_type_class_ref(type);
+
+	/* Register transform functions explicitly, we need own routines */
+ 	g_value_register_transform_func (G_TYPE_STRING, G_TYPE_FLOAT, __transform_string_to_float);
+ 	g_value_register_transform_func (G_TYPE_STRING, G_TYPE_BOOLEAN, __transform_string_to_boolean);
 }
 
 void midgard_close(void)
