@@ -35,25 +35,45 @@ midgard_dbobject_constructor (GType type,
 	MIDGARD_DBOBJECT(object)->dbpriv = g_new(MidgardDBObjectPrivate, 1);
 	MIDGARD_DBOBJECT(object)->dbpriv->mgd = NULL; /* read only */
 	MIDGARD_DBOBJECT(object)->dbpriv->guid = NULL;
+	MIDGARD_DBOBJECT(object)->dbpriv->datamodel = NULL;
+	MIDGARD_DBOBJECT(object)->dbpriv->row = -1;	
+	MIDGARD_DBOBJECT(object)->dbpriv->has_metadata = TRUE;
 
 	MIDGARD_DBOBJECT (object)->dbpriv->storage_data =
-		MIDGARD_OBJECT_GET_CLASS (object)->dbpriv->storage_data;
+		MIDGARD_DBOBJECT_GET_CLASS (object)->dbpriv->storage_data;
 
 	return G_OBJECT(object);
 }
 
 static void 
 midgard_dbobject_dispose (GObject *object)
+{
+	parent_class->dispose (object);
+}
+
+static void 
+midgard_dbobject_finalize (GObject *object)
 {
 	MidgardDBObject *self = MIDGARD_DBOBJECT(object);
 
+	if (!self)
+		return;
+
+	if (!self->dbpriv)
+		return;
+
 	g_free((gchar *)self->dbpriv->guid);
 	self->dbpriv->guid = NULL;
 
+	if (self->dbpriv->datamodel)
+		g_object_unref(self->dbpriv->datamodel);
+
+	self->dbpriv->row = -1;
+
 	g_free(self->dbpriv);
 	self->dbpriv = NULL;
 
-	parent_class->dispose (object);
+	parent_class->finalize (object);
 }
 
 static const MidgardConnection *__get_connection(MidgardDBObject *self)
@@ -70,8 +90,15 @@ midgard_dbobject_class_init (MidgardDBObjectClass *klass, gpointer g_class_data)
 	
 	object_class->constructor = midgard_dbobject_constructor;
 	object_class->dispose = midgard_dbobject_dispose;
+	object_class->finalize = midgard_dbobject_finalize;
 
 	klass->get_connection = __get_connection;
+
+	klass->dbpriv = g_new(MidgardDBObjectPrivate, 1);
+	klass->dbpriv->create_storage = NULL;
+	klass->dbpriv->update_storage = NULL;
+	klass->dbpriv->storage_exists = NULL;
+	klass->dbpriv->delete_storage = NULL;
 }
 
 /* Registers the type as a fundamental GType unless already registered. */ 
