@@ -8,16 +8,14 @@
 #include <glib.h>
 #include "midgard_config_auto.h"
 
-typedef struct _mgd_userinfo mgd_userinfo;
-typedef struct _midgard_mysql midgard_mysql;
-typedef struct _midgard_res midgard_res;
-typedef struct _qlimit qlimit;
-typedef struct _MgdSchemaTypeAttr MgdSchemaTypeAttr;
 typedef struct MidgardTypeHolder MidgardTypeHolder;
-typedef struct MidgardConnection MidgardConnection;
+typedef struct _MidgardConnection MidgardConnection;
 typedef struct _MidgardObjectClass MidgardObjectClass;
-
 typedef struct _MidgardUser MidgardUser;
+typedef struct _MidgardMetadata MidgardMetadata;
+typedef struct _MidgardMetadata midgard_metadata;
+typedef struct _MidgardMetadataClass MidgardMetadataClass;
+
 
 typedef enum {
 	MIDGARD_AUTHTYPE_NORMAL = 0,
@@ -25,10 +23,6 @@ typedef enum {
 	MIDGARD_AUTHTYPE_TRUST
 } MidgardTypeAuth;
 
-/* Temporary to satisfy compiler and linker 
- * Remove when midgard_user_is_root is implemented */
-#define midgard_core_isroot(a) (0 < 1)
-
-#define MIDGARD_PACKAGE_NAME "midgard-2.0"
+#define MIDGARD_PACKAGE_NAME "midgard2"
 
 #endif /* MIDGARD_DEFS_H */
