@@ -105,7 +105,7 @@ static GParamSpec **_midgard_object_class_paramspec()
 
 /* Initialize instance for all types that are not MidgardRepligardClass type. */
 static void 
-_object_instance_init(GTypeInstance *instance, gpointer g_class)
+__midgard_object_instance_init(GTypeInstance *instance, gpointer g_class)
 {	
 	MgdObject *self = (MgdObject *) instance;
 	
@@ -118,10 +118,13 @@ _object_instance_init(GTypeInstance *instance, gpointer g_class)
 	self->priv->_params = NULL;
 
 	/* Initialize metadata object, if enabled. */	
-	if (MIDGARD_DBOBJECT_CLASS (g_class)->dbpriv->has_metadata)
-		self->metadata = midgard_metadata_new(self);	
-	else 
+	if (MIDGARD_DBOBJECT_CLASS (g_class)->dbpriv->has_metadata) {
+		self->metadata = midgard_metadata_new(self);
+		/* Add weak reference */
+		g_object_add_weak_pointer (G_OBJECT (self), (gpointer) self->metadata);	
+	} else {
 		self->metadata = NULL;
+	}
 }
                 
 /* AB: This is shortcut macro for traversing through class hierarchy (from child to ancestor)
@@ -144,7 +147,7 @@ _object_instance_init(GTypeInstance *instance, gpointer g_class)
 
 /* AB: Handle property assignments. Despite its simplicity, this is *very* important function */
 static void
-_object_set_property (GObject *object, guint prop_id, 
+__midgard_object_set_property (GObject *object, guint prop_id, 
     const GValue *value, GParamSpec   *pspec)
 {	
 	gint prop_id_local = 0;
@@ -183,7 +186,7 @@ _object_set_property (GObject *object, guint prop_id,
 
 /* Get object's property */
 static void
-_object_get_property (GObject *object, guint prop_id,
+__midgard_object_get_property (GObject *object, guint prop_id,
 		GValue *value, GParamSpec   *pspec)
 {
 	gint prop_id_local = 0;
@@ -220,16 +223,42 @@ _object_get_property (GObject *object, guint prop_id,
 	}
 }
 
+static void 
+__mgdschema_object_dispose (GObject *object)
+{
+	MidgardObject *self = MIDGARD_OBJECT (object);
+
+	if (self->metadata != NULL && G_IS_OBJECT(self->metadata)) {
+		/* Remove weak reference */
+		g_object_remove_weak_pointer (G_OBJECT (self), (gpointer) self->metadata);
+		/* Call destructor */
+		g_object_unref (self->metadata);
+		self->metadata = NULL;
+	}
+
+	/* Free object's parameters */
+	if (self->priv->parameters != NULL) {
+		
+		GSList *_param = self->priv->parameters;
+		for (; _param; _param = _param->next) {
+			g_object_unref(_param->data);	
+		}
+		g_slist_free(_param);
+		self->priv->parameters = NULL;
+	}
+
+	__mgdschema_parent_class->dispose (object);
+}
+
 /* 
- * Finalizer for GMidgardObject instance.
+ * Finalizer for MidgardObject instance.
  * Cleans up all allocated data. As optimization, it handles all data
  * which belongs to its ancestors up to but not inluding GObject.
  * It is really makes no sense to call this function recursively
  * for each ancestor because we already know object's structure.
  * For GObject we call its finalizer directly.
  */
-
-static void _object_finalize (GObject *object) 
+static void __mgdschema_object_finalize (GObject *object) 
 {
 	guint idx;
 	MgdSchemaTypeAttr *priv;
@@ -244,26 +273,11 @@ static void _object_finalize (GObject *object)
 	g_free(self->priv->exported);
 	g_free(self->priv->imported);
 	
-	/* Free object's parameters */
-	if (self->priv->parameters != NULL) {
-		
-		GSList *_param = self->priv->parameters;
-		for (; _param; _param = _param->next) {
-			g_object_unref(_param->data);	
-		}
-		g_slist_free(_param);
-	}
-
 	if (self->priv->_params != NULL)
 		g_hash_table_destroy(self->priv->_params);
 
 	g_free(self->priv);
 	self->priv = NULL;
-
-	if (self->metadata != NULL && G_IS_OBJECT(self->metadata)) {
-		g_object_unref(self->metadata);
-		self->metadata = NULL;
-	}
 	
 	GType current_type = G_TYPE_FROM_INSTANCE(object); 
 
@@ -1216,9 +1230,9 @@ __mgdschema_class_init(gpointer g_class, gpointer class_data)
 
 	__mgdschema_parent_class = g_type_class_peek_parent (g_class);
 
-	gobject_class->set_property = _object_set_property;
-	gobject_class->get_property = _object_get_property;
-	gobject_class->finalize = _object_finalize;
+	gobject_class->set_property = __midgard_object_set_property;
+	gobject_class->get_property = __midgard_object_get_property;
+	gobject_class->finalize = __mgdschema_object_finalize;
 	gobject_class->constructor = __mgdschema_object_constructor;
         gobject_class->dispose = __mgdschema_object_dispose;
 
@@ -1278,19 +1292,16 @@ __mgdschema_class_init(gpointer g_class, gpointer class_data)
 }
 
 static void
-__add_core_properties(MgdSchemaTypeAttr *type_attr)
+__add_core_properties (MgdSchemaTypeAttr *type_attr)
 {
 	/* GUID */
-	MgdSchemaPropertyAttr *prop_attr =
-		_mgd_schema_property_attr_new();
+	MgdSchemaPropertyAttr *prop_attr = midgard_core_schema_type_property_attr_new();
 	prop_attr->name = g_strdup ("guid");
 	prop_attr->gtype = MGD_TYPE_GUID;
-	prop_attr->field = g_strdup("guid");
-	prop_attr->table = g_strdup(type_attr->table);
-	prop_attr->tablefield = 
-		g_strjoin(".", type_attr->table, "guid", NULL);
-	g_hash_table_insert(type_attr->prophash,
-			g_strdup((gchar *)"guid"), prop_attr);
+	prop_attr->field = g_strdup ("guid");
+	prop_attr->table = g_strdup (type_attr->table);
+	prop_attr->tablefield = g_strjoin (".", type_attr->table, "guid", NULL);
+	g_hash_table_insert (type_attr->prophash, g_strdup((gchar *)"guid"), prop_attr);
 	
 	return;
 }
@@ -1329,16 +1340,12 @@ __mgdschema_object_constructor (GType type,
 	return object;
 }
 
-static void 
-__mgdschema_object_dispose (GObject *object)
-{
-	__mgdschema_parent_class->dispose (object);
-}
-
 GType
-midgard_type_register(const gchar *class_name, MgdSchemaTypeAttr *data, GType parent_type)
+midgard_type_register (MgdSchemaTypeAttr *type_data, GType parent_type)
 {
-	GType class_type = g_type_from_name(class_name);
+	gchar *classname = type_data->name;
+
+	GType class_type = g_type_from_name (classname);
 
         if (class_type) {
                 return class_type;
@@ -1346,33 +1353,33 @@ midgard_type_register(const gchar *class_name, MgdSchemaTypeAttr *data, GType pa
 
         {
                 GTypeInfo *midgard_type_info = g_new0 (GTypeInfo, 1);
-		if (data == NULL)
-			data = g_new(MgdSchemaTypeAttr, 1);
+
+		/* FIXME, does it make sense? */
+		if (type_data == NULL)
+			type_data = g_new(MgdSchemaTypeAttr, 1);
 
                 /* our own class size is 0 but it should include space for a parent, therefore add it */
-                midgard_type_info->class_size = sizeof(MidgardObjectClass);
+                midgard_type_info->class_size = sizeof (MidgardObjectClass);
                 midgard_type_info->base_init = NULL;
                 midgard_type_info->base_finalize = NULL;
                 midgard_type_info->class_init  = __mgdschema_class_init;
                 midgard_type_info->class_finalize  = NULL;
-                midgard_type_info->class_data = data;
+                midgard_type_info->class_data = type_data;
                 /* our own instance size is 0 but it should include space for a parent,
                  * therefore add it */
-                midgard_type_info->instance_size = sizeof(MgdObject);
+                midgard_type_info->instance_size = sizeof (MgdObject);
                 midgard_type_info->n_preallocs = 0;
-                midgard_type_info->instance_init = _object_instance_init;
+                midgard_type_info->instance_init = __midgard_object_instance_init;
                 midgard_type_info->value_table = NULL;
                 
-		GType type = g_type_register_static(
-                                MIDGARD_TYPE_OBJECT, class_name, midgard_type_info, 0);
+		GType type = g_type_register_static (MIDGARD_TYPE_OBJECT, classname, midgard_type_info, 0);
                 
-		if (g_str_equal(class_name, "midgard_attachment"))
+		if (g_str_equal (classname, "midgard_attachment"))
 			_midgard_attachment_type = type;
 
-                g_free(midgard_type_info);
+                g_free (midgard_type_info);
                 return type;   
         }                      
-
 }
 
 /* Workaround for midgard_attachment created as MgdSchema class and type */
@@ -1427,6 +1434,12 @@ __midgard_object_dispose (GObject *object)
 	__midgard_object_parent_class->dispose (object);
 }
 
+static void 
+__midgard_object_finalize (GObject *object)
+{
+	__midgard_object_parent_class->finalize (object);
+}
+
 static void
 __midgard_object_class_init (MidgardObjectClass *klass, gpointer g_class_data)
 {
@@ -1441,8 +1454,9 @@ __midgard_object_class_init (MidgardObjectClass *klass, gpointer g_class_data)
 
 	g_class->constructor = __midgard_object_constructor;
 	g_class->dispose = __midgard_object_dispose;
-	g_class->set_property = _object_set_property;
-	g_class->get_property = _object_get_property;
+	g_class->set_property = __midgard_object_set_property;
+	g_class->get_property = __midgard_object_get_property;
+	g_class->finalize = __midgard_object_finalize;
 
 	MgdSchemaTypeAttr *data = (MgdSchemaTypeAttr *) g_class_data;
 	guint idx;
