@@ -219,6 +219,15 @@ MgdObject *midgard_object_class_get_object_by_guid (	MidgardConnection *mgd,
 	guint aval = 0;
 	MIDGARD_GET_UINT_FROM_VALUE(aval, action_value);
 
+	/* workaround for incorrect repligard.object_action which holds varchar type in mjolnir 9.09.0 */
+	/* TODO: Remove in Ratatoskr+1 */
+	if (G_VALUE_HOLDS_STRING (action_value)) {
+
+		gchar *strval = g_value_get_string (action_value);
+		if (strval)
+			aval = atoi ((const gchar *)strval);
+	}
+
 	switch(aval) {
 		
 		case MGD_OBJECT_ACTION_DELETE:
@@ -619,3 +628,27 @@ midgard_object_class_get_metadata_class (MidgardObjectClass *klass)
 
 	return g_type_class_peek(g_type_from_name(type_attr->metadata_class));
 }
+
+/**
+ * midgard_object_class_get_schema_value:
+ * @klass: MidgardObjectClass derived class pointer
+ * @name: node's name declared for given @klass
+ *
+ * Returns: value for given node's @name 
+ *
+ * Since: 9.09.1
+ */
+const gchar *
+midgard_object_class_get_schema_value (MidgardObjectClass *klass, const gchar *name)
+{
+	g_return_val_if_fail (klass != NULL, NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+
+	MgdSchemaTypeAttr *type_attr = midgard_core_class_get_type_attr (MIDGARD_DBOBJECT_CLASS (klass));	
+
+	if (!type_attr)
+		return NULL;
+
+	return g_hash_table_lookup (type_attr->user_values, (gpointer) name);
+}
+
