@@ -561,16 +561,21 @@ static GList *midgard_query_builder_execute_or_count(MidgardQueryBuilder *builde
 		}
 	}
 
+	g_signal_emit (builder, MIDGARD_QUERY_BUILDER_GET_CLASS (builder)->signal_id_execution_start, 0);
+
 	GList *list = midgard_core_qb_set_object_from_query(builder, select_type, NULL);
+
 	if (list == NULL) {
+
 		if (holder)
 			holder->elements = 0;
-
-		return NULL;
+	} else {
+		
+		if (holder)
+			holder->elements = g_list_length(list);
 	}
 
-	if (holder)
-		holder->elements = g_list_length(list);
+	g_signal_emit (builder, MIDGARD_QUERY_BUILDER_GET_CLASS (builder)->signal_id_execution_end, 0);
 
 	return list;
 }
@@ -917,7 +922,8 @@ static void __mqb_set_metadata(MidgardMetadata *mdata, GdaDataModel *model, gint
 	return;
 }
 
-GList *midgard_core_qb_set_object_from_query(MidgardQueryBuilder *builder, guint select_type, MgdObject *nobject)
+GList *
+midgard_core_qb_set_object_from_query (MidgardQueryBuilder *builder, guint select_type, MgdObject *nobject)
 {
         g_assert(builder != NULL);
 
@@ -1036,10 +1042,6 @@ GList *midgard_core_qb_set_object_from_query(MidgardQueryBuilder *builder, guint
 				
 				if(G_IS_VALUE(gvalue)) {
 
-					guint puint = 0;
-					gint pint = 0;
-					gboolean pbool = 0;
-
 					if (!pspec) {
 						
 						g_warning("Failed to found (unregistered) %s property (%s class)", 
@@ -1047,31 +1049,29 @@ GList *midgard_core_qb_set_object_from_query(MidgardQueryBuilder *builder, guint
 						continue;
 					}
 
-					switch(pspec->value_type) {
+					if (pspec->value_type != G_VALUE_TYPE (gvalue)) {
 
-						case G_TYPE_INT:
-							MIDGARD_GET_INT_FROM_VALUE(pint, gvalue);
-							g_object_set(G_OBJECT(object), coltitle, pint, NULL);
-							break;
+						GValue _convert = {0, };
+						g_value_init (&_convert, pspec->value_type);	
+				
+						if (g_value_transform (gvalue, &_convert)) {
 
-						case G_TYPE_UINT:
-							MIDGARD_GET_UINT_FROM_VALUE(puint, gvalue);
-							g_object_set(G_OBJECT(object), coltitle, puint, NULL);
-							break;
+							g_object_set_property (G_OBJECT (object), coltitle, &_convert);
+					
+						} else {
 
-						case G_TYPE_BOOLEAN:
-							if (G_VALUE_TYPE(gvalue) != G_TYPE_BOOLEAN) {
-								MIDGARD_GET_BOOLEAN_FROM_VALUE(pbool, gvalue);
-								g_object_set(G_OBJECT(object), coltitle, pbool, NULL);
-							} else {
-								g_object_set_property(G_OBJECT(object), coltitle, gvalue);
-							}
-							break;
+							g_warning ("Failed to convert %s to %s for %s property",
+									G_VALUE_TYPE_NAME (gvalue),
+									G_VALUE_TYPE_NAME (&_convert), 
+									coltitle);
+						}
 
-						default:
-							g_object_set_property(G_OBJECT(object), coltitle, gvalue);
-							break;
-					}
+						g_value_unset (&_convert);
+
+					} else {
+
+						g_object_set_property(G_OBJECT(object), coltitle, gvalue);
+					}	
 				
 				} else if (gda_value_is_null(gvalue)) {			
 
@@ -1188,6 +1188,28 @@ static void _midgard_query_builder_class_init(
 	klass->include_deleted = midgard_query_builder_include_deleted;
 	klass->execute = midgard_query_builder_execute;
 	klass->count = midgard_query_builder_count;
+
+	klass->signal_id_execution_start =
+		g_signal_new("execution-start",
+				G_TYPE_FROM_CLASS(g_class),
+				G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+				G_STRUCT_OFFSET (MidgardQueryBuilderClass, execution_start),
+				NULL, /* accumulator */
+				NULL, /* accu_data */
+				g_cclosure_marshal_VOID__VOID,
+				G_TYPE_NONE,
+				0);
+
+	klass->signal_id_execution_end =
+		g_signal_new("execution-end",
+				G_TYPE_FROM_CLASS(g_class),
+				G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
+				G_STRUCT_OFFSET (MidgardQueryBuilderClass, execution_end),
+				NULL, /* accumulator */
+				NULL, /* accu_data */
+				g_cclosure_marshal_VOID__VOID,
+				G_TYPE_NONE,
+				0);
 }
 
 static void _midgard_query_builder_instance_init(
